==> estateplat-common-1.1.0-20160819.023516-157-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 土地所有权
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_tdsyq")
public class BdcTdsyq extends QllxParent implements Serializable {
//    @Id
//    private String qlid;//权力id

//    private String bdcdyid;//不动产单元Id

    private Double nydmj;//农用地面积

    private Double gdmj;//耕地面积

    private Double ntmj;//基本农田面积

    private Double ldmj;//林地面积

    private Double cdmj;//草地面积

    private Double qtmj;//其他面积

    private Double jsydmj;//建设用地面积

    private Double wlydmj;//未利用地面积

    private String qllx;//权利类型

    private String gyqk;//共有情况

    private Date djsj;//登记时间

    private String dbr;//登簿人

    private String fj;//附记

    private Integer qszt;//权属状态

    private Date qlqssj;//权利起始时间

    private Date qljssj;//权利结束时间


    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public Double getNydmj() {
        return nydmj;
    }

    public void setNydmj(Double nydmj) {
        this.nydmj = nydmj;
    }

    public Double getGdmj() {
        return gdmj;
    }

    public void setGdmj(Double gdmj) {
        this.gdmj = gdmj;
    }

    public Double getNtmj() {
        return ntmj;
    }

    public void setNtmj(Double ntmj) {
        this.ntmj = ntmj;
    }

    public Double getLdmj() {
        return ldmj;
    }

    public void setLdmj(Double ldmj) {
        this.ldmj = ldmj;
    }

    public Double getCdmj() {
        return cdmj;
    }

    public void setCdmj(Double cdmj) {
        this.cdmj = cdmj;
    }

    public Double getQtmj() {
        return qtmj;
    }

    public void setQtmj(Double qtmj) {
        this.qtmj = qtmj;
    }

    public Double getJsydmj() {
        return jsydmj;
    }

    public void setJsydmj(Double jsydmj) {
        this.jsydmj = jsydmj;
    }

    public Double getWlydmj() {
        return wlydmj;
    }

    public void setWlydmj(Double wlydmj) {
        this.wlydmj = wlydmj;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }
}

==> estateplat-common-1.2.3-20180109.015111-8-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 土地所有权
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_tdsyq")
public class BdcTdsyq extends QllxParent implements Serializable {
//    @Id
//    private String qlid;//权力id

//    private String bdcdyid;//不动产单元Id

    private Double nydmj;//农用地面积

    private Double gdmj;//耕地面积

    private Double ntmj;//基本农田面积

    private Double ldmj;//林地面积

    private Double cdmj;//草地面积

    private Double qtmj;//其他面积

    private Double jsydmj;//建设用地面积

    private Double wlydmj;//未利用地面积

    private String qllx;//权利类型

    private String gyqk;//共有情况

    private Date djsj;//登记时间

    private String dbr;//登簿人

    private String fj;//附记

    private Integer qszt;//权属状态

    private Date qlqssj;//权利起始时间

    private Date qljssj;//权利结束时间
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public Double getNydmj() {
        return nydmj;
    }

    public void setNydmj(Double nydmj) {
        this.nydmj = nydmj;
    }

    public Double getGdmj() {
        return gdmj;
    }

    public void setGdmj(Double gdmj) {
        this.gdmj = gdmj;
    }

    public Double getNtmj() {
        return ntmj;
    }

    public void setNtmj(Double ntmj) {
        this.ntmj = ntmj;
    }

    public Double getLdmj() {
        return ldmj;
    }

    public void setLdmj(Double ldmj) {
        this.ldmj = ldmj;
    }

    public Double getCdmj() {
        return cdmj;
    }

    public void setCdmj(Double cdmj) {
        this.cdmj = cdmj;
    }

    public Double getQtmj() {
        return qtmj;
    }

    public void setQtmj(Double qtmj) {
        this.qtmj = qtmj;
    }

    public Double getJsydmj() {
        return jsydmj;
    }

    public void setJsydmj(Double jsydmj) {
        this.jsydmj = jsydmj;
    }

    public Double getWlydmj() {
        return wlydmj;
    }

    public void setWlydmj(Double wlydmj) {
        this.wlydmj = wlydmj;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }
}
